@@ -26,7 +26,7 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 
 package Config::Model::Tk::AnyViewer;
-$Config::Model::Tk::AnyViewer::VERSION = '1.348';
+$Config::Model::Tk::AnyViewer::VERSION = '1.350';
 use strict;
 use warnings;
 use Carp;
@@ -72,7 +72,7 @@ sub add_header {
     $cw->{config_class_name} = $class;
 
     my $label = "$type: ";
-    $label .= $item->location || "Class $class";
+    $label .= $item->location_short || "Class $class";
     my $f = $cw->Frame;
 
     $f->Label( -image => $img{ lc($type) }, -anchor => 'w' )->pack( -side => 'left' );
