@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::LeafEditor;
-$Config::Model::Tk::LeafEditor::VERSION = '1.348';
+$Config::Model::Tk::LeafEditor::VERSION = '1.350';
 use strict;
 use warnings;
 use Carp;
@@ -60,7 +60,7 @@ sub Populate {
         or $vt eq 'reference';
 
     my $ed_frame = $cw->Frame(qw/-relief raised -borderwidth 2/)->pack(@pack_args);
-    $ed_frame->Label( -text => 'Value' )->pack();
+    $ed_frame->Label( -text => 'Edit value' )->pack();
 
     my $balloon = $cw->Balloon( -state => 'balloon' );
 
